@@ -35,7 +35,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL.php,v 1.17 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL.php,v 1.18 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -43,7 +43,7 @@
 /**
  * С
  */
-define('SYL_VERSION', '0.9.0');
+define('SYL_VERSION', '0.9.1');
 
 /**
  * ١ǥ쥯ȥ
@@ -69,20 +69,24 @@ define('SYL_ENCODE_MAIL',     'ISO-2022-JP');
 define('SYL_ENCODE_AJAX',     'UTF-8');
 define('SYL_ENCODE_XML',      'UTF-8');
 
-// PHP 5.1ʾѥॾ
+/**
+ * ॾPHP 5.1ʾ
+ */
 if (version_compare(PHP_VERSION, '5.1.0', '>=') && !ini_get('date.timezone')) {
     date_default_timezone_set('Asia/Tokyo');
 }
 
 /**
- * PHPƥ२顼¸ե饰
+ * PHPƥ२顼¸
+ * ȤǥƤʤ硢¸
  */
-define('SYL_LOG_SYSTEM_ERROR', true);
-/**
- * PHPƥ२顼¸ե
- */
-define('SYL_LOG_SYSTEM_ERROR_FILE', SYL_DIR . '/var/syslogs/phperror_' . date('Ymd') . '.log');
-
+if (!ini_get('log_errors')) {
+    $_log = SYL_DIR . '/var/syslogs/phperror_' . date('Ymd') . '.log';
+    if (is_writable(dirname($_log))) {
+        ini_set('log_errors', true);
+        ini_set('error_log', $_log);
+    }
+}
 
 // ȥɤ߹
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Controller.php';
