@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.11 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.12 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.11 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.12 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
@@ -116,7 +116,7 @@ class SyL_ConfigFilters extends SyL_Config
      *
      * @access public
      */
-    function parseXML()
+    function parseXml()
     {
         if (SYL_WEBAPP_CACHE_DIR) {
             // åѤ
@@ -125,12 +125,12 @@ class SyL_ConfigFilters extends SyL_Config
             $cache->setCacheDir(SYL_WEBAPP_CACHE_DIR . '/filters');
             $this->config = $cache->read($this->file_names);
             if (!$this->config) {
-                parent::parseXML();
+                parent::parseXml();
                 $cache->write($this->config);
             }
         } else {
             // åѤʤ
-            parent::parseXML();
+            parent::parseXml();
         }
     }
 
