@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestParameterSession.php,v 1.5 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestParameterSession.php,v 1.6 2007/03/17 13:53:08 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,47 +44,18 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_RequestParameter.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestParameterSession.php,v 1.5 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestParameterSession.php,v 1.6 2007/03/17 13:53:08 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestParameterSession extends SyL_RequestParameter
 {
     /**
-     * å̾
+     * åURLѥ
      *
      * @access private
      * @var string
      */
-    var $name = SYL_SESSION_NAME;
-    /**
-     * åѥ
-     *
-     * @access private
-     * @var string
-     */
-    var $path = SYL_SESSION_PATH;
-    /**
-     * ɥᥤ
-     *
-     * @access private
-     * @var string
-     */
-    var $domain = SYL_SESSION_DOMAIN;
-    /**
-     * å
-     *
-     * @access private
-     * @var string
-     */
-    var $cache = SYL_SESSION_CACHE;
-    /**
-     * 奢
-     *
-     * @access private
-     * @var bool
-     */
-    var $secure = SYL_SESSION_SECURE;
-
+    var $path = '';
     /**
      * å󳫻ϥե饰
      *
@@ -110,21 +81,19 @@ class SyL_RequestParameterSession extends SyL_RequestParameter
     {
         if (!$this->start) {
             // å̾򥻥å
-            if ($this->name != '') {
-                session_name($this->name);
+            if (SYL_SESSION_NAME) {
+                session_name(SYL_SESSION_NAME);
             }
             // åѹ
-            if (SYL_SESSION_CACHE != '') {
-                session_cache_limiter($this->cache);
+            if (SYL_SESSION_CACHE) {
+                session_cache_limiter(SYL_SESSION_CACHE);
             }
-            // åƼѥ᡼
-            $session_path   = ($this->path != '')   ? $this->path   : '/';
-            $session_domain = ($this->domain != '') ? $this->domain : null;
-            $session_secure = ($this->secure) ? true : false;
-            session_set_cookie_params(0, $session_path, $session_domain, $session_secure);
 
-            // PHP 4.3.3 ʹ
-            //session_regenerate_id();
+            // åƼѥ᡼
+            $this->path     = SYL_SESSION_PATH   ? SYL_SESSION_PATH   : '/';
+            $session_domain = SYL_SESSION_DOMAIN ? SYL_SESSION_DOMAIN : null;
+            $session_secure = SYL_SESSION_SECURE ? true : false;
+            session_set_cookie_params(0, $this->path, $session_domain, $session_secure);
 
             if (strtolower(SYL_SESSION_TYPE) == 'db') {
                 // DBå
@@ -134,6 +103,10 @@ class SyL_RequestParameterSession extends SyL_RequestParameter
 
             // å󳫻
             $this->startSession();
+            // åIDѹ
+            if (SYL_SESSION_REGENERATE) {
+                $this->regenerateSession();
+            }
         }
     }
 
@@ -142,11 +115,14 @@ class SyL_RequestParameterSession extends SyL_RequestParameter
      *
      * @access public
      */
-    function startSession()
+    function startSession($old_session_data=null)
     {
         if (!$this->start) {
             session_start();
             $this->start = true;
+            if (is_array($old_session_data)) {
+                $_SESSION = $old_session_data;
+            }
             $this->parameters =& $_SESSION;
         }
     }
@@ -162,6 +138,34 @@ class SyL_RequestParameterSession extends SyL_RequestParameter
         return $this->start;
     }
 
+    /**
+     * åIDѹ
+     * å󳫻ϸ˼¹Ԥ
+     *
+     * @access public
+     */
+    function regenerateSession()
+    {
+        if (version_compare(PHP_VERSION, '5.1.0', '>=')) {
+            session_regenerate_id(true);
+        } else {
+            $old_session_id   = $this->getSessionId();
+            $old_session_data = $this->parameters;
+            $_SESSION = array();
+            session_destroy();
+            $this->start = false;
+
+            $session_dir = session_save_path();
+            $new_session_id = '';
+            do {
+              $new_session_id = md5(uniqid(rand(), true));
+            } while (file_exists("{$session_dir}/sess_{$new_session_id}"));
+            session_id($new_session_id);
+
+            $this->startSession($old_session_data);
+        }
+    }
+
     /**
      * ѥ᡼
      * 
@@ -201,6 +205,11 @@ class SyL_RequestParameterSession extends SyL_RequestParameter
             session_write_close();
             $this->start = false;
             parent::deleteParameters();
+
+            // 2ܰʹߤsession_start()ǥåȯԤʤб
+            if (ini_get('session.use_cookies')) {
+              ini_set('session.use_cookies', '0');
+            }
         }
     }
 
@@ -223,7 +232,7 @@ class SyL_RequestParameterSession extends SyL_RequestParameter
      */
     function getSidQuery()
     {
-        return session_name() . '=' . session_id();
+        return session_name() . '=' . $this->getSessionId();
     }
 }
 
