@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.10 2007/01/28 07:13:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -67,7 +67,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Router.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.10 2007/01/28 07:13:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterParameter extends SyL_Router
@@ -106,6 +106,10 @@ class SyL_RouterParameter extends SyL_Router
             $pathinfo_file  = basename($pathinfo);
             $pathinfo_dir   = dirname($pathinfo);
             $pathinfo_files = explode($this->action_delimiter, $pathinfo_file, 2);
+            // windowsб
+            if ($pathinfo_dir == '\\') {
+                $pathinfo_dir = '';
+            }
             if ($pathinfo_dir != '/') {
                 $pathinfo_dir = $pathinfo_dir . '/';
             }
