@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.15 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.15 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -283,8 +283,13 @@ echo "</pre>";
                     if (method_exists($component, $funcs[1])) {
                         $this->component_returns[$method_name] = call_user_func_array(array(&$component, $funcs[1]), $value_args);
                     } else {
-                        $this->log('info', "Method injection failed: method not found (" . get_class($component) . ".{$funcs[1]})");
-                        $this->component_returns[$method_name] = null;
+                        // ͽʤ᥽åɤμ¹Ԥϥ顼
+                        if (class_exists('SyL_Response')) {
+                            $this->log('warn', "Method injection failed: method not found (" . get_class($component) . ".{$funcs[1]})");
+                            SyL_Response::redirect404();
+                        } else {
+                            trigger_error("[SyL error] Method injection failed: method not found (" . get_class($component) . ".{$funcs[1]})", E_USER_ERROR);
+                        }
                     }
                     break;
 
@@ -489,10 +494,10 @@ echo "</pre>";
      * @access private
      * @param string ¸ʸ
      */
-    function log($type, $value)
+    function log($type, $message)
     {
         if ($this->isComponent('log')) {
-            SyL_Loggers::$type("[Container] " . $value);
+            SyL_Loggers::$type("[Container] " . $message);
         }
     }
 }
