@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.18 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.19 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,17 +37,11 @@
  */
 ob_start();
 ob_implicit_flush(0);
+
 /**
  * magic_quotes_runtime -> off
  */
 set_magic_quotes_runtime(0);
-/**
- * PHPƥ२顼¸
- */
-if (SYL_LOG_SYSTEM_ERROR && is_writable(dirname(SYL_LOG_SYSTEM_ERROR_FILE))) {
-    ini_set('log_errors', SYL_LOG_SYSTEM_ERROR);
-    ini_set('error_log', SYL_LOG_SYSTEM_ERROR_FILE);
-}
 
 /**
  * եɤ߹९饹
@@ -75,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.18 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.19 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -128,10 +122,20 @@ class SyL_Controller
      *
      * SyL_ErrorǻѤƤ
      *
-     * @access private
+     * @access public
      * @var string
      */
     var $error_handler_method = 'errorStream';
+    /**
+     * 㳰ϥɥ᥽å̾
+     * ''ξ㳰ϥɥꤷʤ
+     *
+     * SyL_ErrorǻѤƤ
+     *
+     * @access public
+     * @var string
+     */
+    var $exception_handler_method = 'exceptionStream';
     /**
      * ˴᥽å̾
      * ''ξϽ˴᥽åɤꤷʤ
@@ -302,14 +306,40 @@ class SyL_Controller
      */
     function finalStream()
     {
+        // ̥ǥХå
+        if (class_exists('SyL_Loggers') && function_exists('memory_get_usage')) {
+            $debug = '[Controller] Memory Status  current: ' . number_format(floor(memory_get_usage()/1024)) . 'KB';
+            if (function_exists('memory_get_peak_usage')) {
+                $debug .= ' max: ' . number_format(floor(memory_get_peak_usage()/1024)) . 'KB';
+            }
+            SyL_Loggers::debug($debug);
+        }
+
         // ٥ȼ¹
         $this->raiseEvent('finalStream');
     }
 
+    /**
+     * 㳰ϥɥ¹Խ
+     *
+     * @access protected
+     * @param object 㳰֥
+     */
+    function exceptionStream($ex)
+    {
+        $this->errorStream(E_USER_ERROR, $ex->getMessage(), $ex->getFile(), $ex->getLine(), array(), $ex->getTrace());
+    }
+
     /**
      * 顼ϥɥ¹Խ
      *
      * @access protected
+     * @param int 顼Υ٥
+     * @param string 顼å
+     * @param string ե
+     * @param int ֹ
+     * @param array ƥ
+     * @param array Хåȥ졼
      */
     function errorStream()
     {
@@ -324,15 +354,28 @@ class SyL_Controller
             for ($i=0; $i<5; $i++) {
                 $this->error[$i] = func_get_arg($i);
             }
-            $this->error[5] = debug_backtrace();
-            // errorStream()᥽åɤϺ
-            array_shift($this->error[5]);
+            if (func_num_args() == 6) {
+                $this->error[5] = func_get_arg(5);
+            } else {
+                $this->error[5] = debug_backtrace();
+                // errorStream()᥽åɤϺ
+                array_shift($this->error[5]);
+            }
+
+            if (count($this->error[5]) > 0) {
+                if (!isset($this->error[5][0]['file'])) {
+                    $this->error[5][0]['file'] = $this->error[2];
+                }
+                if (!isset($this->error[5][0]['line'])) {
+                    $this->error[5][0]['line'] = $this->error[3];
+                }
+            }
 
             // ٥ȼ¹
             $this->raiseEvent('errorStream');
             exit;
         } else {
-            $error_message = "[SyL_error] Background error logging. level " . func_get_arg(0) . " message: " . func_get_arg(1) . " file: " . func_get_arg(2) . " line: " . func_get_arg(3);
+            $error_message = "[SyL_error] Background logging out of error_reporting. level: " . func_get_arg(0) . " message: " . func_get_arg(1) . " file: " . func_get_arg(2) . " line: " . func_get_arg(3);
             SyL_Loggers::info($error_message);
         }
     }
@@ -380,6 +423,28 @@ class SyL_Controller
         return isset($this->error[0]) ? $this->error[0] : '';
     }
 
+    /**
+     * 顼ե
+     * 
+     * @access public
+     * @return string 顼ե
+     */
+    function getErrorFile()
+    {
+        return isset($this->error[2]) ? $this->error[2] : '';
+    }
+
+    /**
+     * 顼Կ
+     * 
+     * @access public
+     * @return string 顼Կ
+     */
+    function getErrorLine()
+    {
+        return isset($this->error[3]) ? $this->error[3] : '';
+    }
+
     /**
      * 顼å
      * 
@@ -388,10 +453,9 @@ class SyL_Controller
      */
     function getErrorMessage()
     {
-        $error_message  = '';
-        $error_message .= isset($this->error[1]) ? $this->error[1] : '';
-        if (isset($this->error[2]) && isset($this->error[3])) {
-            $error_message .= " ({$this->error[2]} on line {$this->error[3]})";
+        $error_message = isset($this->error[1]) ? $this->error[1] : '';
+        if ($error_message) {
+            $error_message .= ' (' . $this->getErrorFile() . ' on line ' . $this->getErrorLine()  . ')';
         }
         return $error_message;
     }
