@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.17 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.18 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.17 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.18 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -139,9 +139,12 @@ class SyL_Error
     function setErrorHandler()
     {
         $error =& SyL_Error::getInstance();
-        if ($error->controller->error_handler_method != '') {
+        if ($error->controller->error_handler_method) {
             if (version_compare(PHP_VERSION, '5.0.0', '>=')) {
                 set_error_handler(array(&$error->controller, $error->controller->error_handler_method), error_reporting());
+                if ($error->controller->exception_handler_method) {
+                    set_exception_handler(array(&$error->controller, $error->controller->exception_handler_method));
+                }
             } else {
                 set_error_handler(array(&$error->controller, $error->controller->error_handler_method));
             }
@@ -175,16 +178,17 @@ class SyL_Error
     /**
      * 顼å
      * 
-     * @access public
-     * @param string 顼å
+     * @access protected
      */
     function getErrorMessages()
     {
         $error_message = $this->controller->getErrorMessage();
-        if (!is_array($error_message)) {
-            $error_message = array($error_message);
+        if ($error_message) {
+            $error_message = '[' . $this->getErrorType() . '] ' . $error_message;
+            return array_merge($this->error_messages, (array)$error_message);
+        } else {
+            return $this->error_messages;
         }
-        return array_merge($this->error_messages, $error_message);
     }
 
     /**
@@ -202,11 +206,42 @@ class SyL_Error
 
     /**
      * 顼ϥɥ顼μ
+     *
+     * ƥץ졼ȥ᥽åɥѥΥƥץ졼
      * 
      * @access public
-     * @param object ǡ֥
      */
-    function errorHandler() {}
+    function errorHandler()
+    {
+        // Хåե󥰥ꥢ
+        if (!headers_sent() && (ob_get_level() > 0)) {
+            ob_clean();
+        }
+
+        // 顼å
+        $error_messages = SYL_ERROR ? $this->getErrorMessages() : array(SYL_ERROR_MESSAGE);
+        // 顼ȥ졼μ
+        $error_trace = SYL_ERROR_TRACE ? $this->getTrace() : '';
+
+        // ֥饹
+        $this->displayError($error_messages, $error_trace);
+
+        // 
+        $this->log();
+        // 顼᡼
+        $this->sendMail();
+    }
+
+    /**
+     * Ķ̥顼
+     * 
+     * @access public
+     * @param array 顼å
+     * @param array 顼ȥ졼
+     */
+    function displayError($error_messages, $error_trace)
+    {
+    }
 
     /**
      * 顼פ֤
@@ -245,7 +280,7 @@ class SyL_Error
             }
         }
 
-        return 'Unknonwn';
+        return 'unknonwn';
     }
 
     /**
@@ -258,19 +293,21 @@ class SyL_Error
     {
         // 顼ȥ졼
         $error_trace = array();
-        foreach (array_reverse($this->controller->getErrorTrace()) as $value) {
+        $i = 1;
+        foreach (array_reverse($this->controller->getErrorTrace()) as $values) {
             // 桼顼ϡtrigger_error״ؿʹߤӽ
             // ¾Υ顼ϡerrorhandler״ؿʹߤӽ
-            if (isset($value['class']) && (strtolower($value['class']) == strtolower(get_class($this)))) {
+            if (isset($values['class']) && (strtolower($values['class']) == strtolower(get_class($this)))) {
                 break;
             }
             $tmp = array();
-            $tmp['file'] = isset($value['file']) ? $value['file'] : '';
-            $tmp['line'] = isset($value['line']) ? $value['line'] : '';
-            if (isset($value['class']) && isset($value['type'])) {
-                $tmp['function'] = $value['class'] . $value['type'] . $value['function'];
+            $tmp['no']   = $i++;
+            $tmp['file'] = isset($values['file']) ? $values['file'] : '-';
+            $tmp['line'] = isset($values['line']) ? $values['line'] : '-';
+            if (isset($values['class']) && isset($values['type'])) {
+                $tmp['function'] = $values['class'] . $values['type'] . $values['function'];
             } else {
-                $tmp['function'] = isset($value['function']) ? $value['function'] : '';
+                $tmp['function'] = (isset($values['function']) && ($values['function'] != 'unknown')) ? $values['function'] : '-';
             }
             $error_trace[] = $tmp;
         }
@@ -280,27 +317,51 @@ class SyL_Error
 
     /**
      * 顼ȥ졼դ顼å
+     * 󥰡᡼
      *
-     * @access public
+     * @access prvate
      * @return string 顼ȥ졼դ顼å
      */
     function getErrorMessageTrace()
     {
         $error_message = '[' . $this->getErrorType() . '] ' . implode($this->eof, $this->getErrorMessages()) . $this->eof;
-        foreach ($this->getTrace() as $value) {
-            $error_message .= "[file] "     . $value['file'] . " ";
-            $error_message .= "[line] "     . $value['line'] . " ";
-            $error_message .= "[function] " . $value['function'] . $this->eof;
+        foreach ($this->getTrace() as $values) {
+            $error_message .= "[file] "     . $values['file']     . " ";
+            $error_message .= "[line] "     . $values['line']     . " ";
+            $error_message .= "[function] " . $values['function'] . $this->eof;
         }
         return $error_message;
     }
 
+    /**
+     * 顼ե
+     *
+     * @access protected
+     * @return string 顼ե
+     */
+    function getErrorFile()
+    {
+        return $this->controller->getErrorFile();
+    }
+
+    /**
+     * 顼Կ
+     *
+     * @access protected
+     * @return int 顼Կ
+     */
+    function getErrorLine()
+    {
+        return $this->controller->getErrorLine();
+    }
+
+
     /**
      * 󥰤¸
      *
      * @access public
      */
-    function logging()
+    function log()
     {
         // ȥ졼դ顼å
         $error_message  = $this->getErrorMessageTrace();
@@ -336,14 +397,13 @@ class SyL_Error
             if ($server == '') {
                 $server = isset($_SERVER['SERVER_NAME']) ? $_SERVER['SERVER_NAME'] : '';
             }
-            if ($server == '') {
-                $server = trim(`hostname`);
-            }
 
             // ȥ졼դ顼å
             $error_message  = $this->getErrorMessageTrace();
             // SyLΥС
-            $version = SYL_VERSION;
+            $version     = SYL_VERSION;
+            $version_php = PHP_VERSION;
+            $uname = php_uname();
 
             $error_mail_subject = "PHP Error occurred - {$server}";
             $error_mail_body = <<< EOF
@@ -355,7 +415,8 @@ Server: {$server}
 {$error_message}
 
 ----------------------------------------
-SyL ver. {$version}
+{$uname}
+PHP {$version_php} on SyL ver. {$version}
 EOF;
 
             // 顼᡼¹
