@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.16 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.17 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.16 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.17 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -146,18 +146,17 @@ class SyL_View
                     $class_file = $class_file1;
                 }
                 break;
-            case 'ajax':
-            case 'default':
-            case 'download':
-            case 'image':
-            case 'js':
-            case 'json':
-            case 'smarty':
-                $class_name = 'SyL_View' . ucfirst($type);
-                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
+            case 'js.ajax':
+            case 'js.login':
+                $class_name = 'SyL_View' . implode('', array_map('ucfirst', explode('.', $type)));
+                $class_file = SYL_INCLUDE_DIR . "/framework/View/Js/{$class_name}.php";
                 break;
             default:
-                trigger_error("[SyL error] View type not found ({$type})", E_USER_ERROR);
+                $class_name = 'SyL_View' . ucfirst($type);
+                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
+                if (!is_file($class_file)) {
+                    trigger_error("[SyL error] Customised View file not found ({$class_file} or {$class_file1})", E_USER_ERROR);
+                }
             }
 
             include_once $class_file;
@@ -179,7 +178,7 @@ class SyL_View
 
         $config_file = SYL_APP_DIR . "/{$this->layout_file_name}";
         $reader =& SyL_Config::getObject('layouts', $config_file, $controller);
-        $reader->parseXML();
+        $reader->parseXml();
         $this->config += $reader->getConfig();
     }
 
@@ -284,17 +283,6 @@ class SyL_View
         return $this->render;
     }
 
-    /**
-     * ɽƤ
-     * 
-     * @access public
-     */
-    function clearRender()
-    {
-        unset($this->render);
-        $this->render = '';
-    }
-
     /**
      * ƥĥפ򥻥å
      * 
