@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilInfo.php,v 1.2 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilInfo.php,v 1.3 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilInfo.php,v 1.2 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilInfo.php,v 1.3 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_UtilInfo
@@ -283,16 +283,7 @@ if (!$display || in_array('CONSTANT', $display)) {
 <hr class="sylinfo">
 <?php
   $skip = true;
-  $syl_action  = array();
-  $syl_dir     = array();
-  $syl_encode  = array();
-  $syl_error   = array();
-  $syl_log     = array();
-  $syl_mail    = array();
-  $syl_router  = array();
-  $syl_session = array();
-  $syl_smarty  = array();
-  $syl_other   = array();
+  $syl_constants  = array();
   foreach (get_defined_constants() as $name => $value) {
     if ($name == 'SYL_VERSION') {
         $skip = false;
@@ -301,132 +292,55 @@ if (!$display || in_array('CONSTANT', $display)) {
     foreach ($not_display_const as $tmp) {
         if (strpos($name, $tmp) !== false) continue 2;
     }
-
+    $type = '';
     if (preg_match('/^SYL_ACTION/', $name)) {
-        $syl_action[$name] = $value;
+        $type = 'ACTION';
     } else if (preg_match('/SMARTY_/', $name)) {
-        $syl_smarty[$name] = $value;
+        $type = 'SMARTY';
     } else if (preg_match('/_DIR$/', $name)) {
-        $syl_dir[$name] = $value;
+        $type = 'DIR';
+    } else if (preg_match('/^SYL_AUTH_/', $name)) {
+        $type = 'AUTH';
     } else if (preg_match('/^SYL_ENCODE_/', $name)) {
-        $syl_encode[$name] = $value;
+        $type = 'ENCODE';
     } else if (preg_match('/^SYL_ERROR/', $name)) {
-        $syl_error[$name] = $value;
+        $type = 'ERROR';
     } else if (preg_match('/^SYL_LOG/', $name)) {
-        $syl_log[$name] = $value;
+        $type = 'LOG';
     } else if (preg_match('/^SYL_MAIL/', $name)) {
-        $syl_mail[$name] = $value;
+        $type = 'MAIL';
     } else if (preg_match('/^SYL_ROUTER_/', $name)) {
-        $syl_router[$name] = $value;
+        $type = 'ROUTER';
+    } else if (preg_match('/^SYL_RESPONSE_/', $name)) {
+        $type = 'RESPONSE';
     } else if (preg_match('/^SYL_SESSION_/', $name)) {
-        $syl_session[$name] = $value;
+        $type = 'SESSION';
     } else {
-        $syl_other[$name] = $value;
+        $type = 'OTHER';
     }
+
+    if (!isset($syl_constants[$type])) {
+        $syl_constants[$type] = array();
+    }
+    $syl_constants[$type][$name] = $value;
   }
+  ksort($syl_constants);
 ?>
 
-<h2>- ACTION -</h2>
+<?php foreach ($syl_constants as $name => $consts) { ?>
+
+<h2>- <?= $name ?> -</h2>
 
 <table border="0" cellpadding="3" width="600" class="sylinfo">
 <tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Value</th></tr>
-<?php foreach ($syl_action as $name => $value) { ?>
+<?php foreach ($consts as $name => $value) { ?>
 <tr><td class="sylinfo_e"><?= htmlspecialchars($name) ?></td><td class="sylinfo_v"><?= SyL_UtilInfo::formatValue($value) ?></td></tr>
 <?php } ?>
 </table>
 <br />
 
-<h2>- DIRECTORY -</h2>
-
-<table border="0" cellpadding="3" width="600" class="sylinfo">
-<tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Value</th></tr>
-<?php foreach ($syl_dir as $name => $value) { ?>
-<tr><td class="sylinfo_e"><?= htmlspecialchars($name) ?></td><td class="sylinfo_v"><?= SyL_UtilInfo::formatValue($value) ?></td></tr>
 <?php } ?>
-</table>
-<br />
-
-<h2>- ENCODE -</h2>
-
-<table border="0" cellpadding="3" width="600" class="sylinfo">
-<tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Value</th></tr>
-<?php foreach ($syl_encode as $name => $value) { ?>
-<tr><td class="sylinfo_e"><?= htmlspecialchars($name) ?></td><td class="sylinfo_v"><?= SyL_UtilInfo::formatValue($value) ?></td></tr>
 <?php } ?>
-</table>
-<br />
-
-<h2>- ERROR -</h2>
-
-<table border="0" cellpadding="3" width="600" class="sylinfo">
-<tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Value</th></tr>
-<?php foreach ($syl_error as $name => $value) { ?>
-<tr><td class="sylinfo_e"><?= htmlspecialchars($name) ?></td><td class="sylinfo_v"><?= SyL_UtilInfo::formatValue($value) ?></td></tr>
-<?php } ?>
-</table>
-<br />
-
-<h2>- LOG -</h2>
-
-<table border="0" cellpadding="3" width="600" class="sylinfo">
-<tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Value</th></tr>
-<?php foreach ($syl_log as $name => $value) { ?>
-<tr><td class="sylinfo_e"><?= htmlspecialchars($name) ?></td><td class="sylinfo_v"><?= SyL_UtilInfo::formatValue($value) ?></td></tr>
-<?php } ?>
-</table>
-<br />
-
-<h2>- MAIL -</h2>
-
-<table border="0" cellpadding="3" width="600" class="sylinfo">
-<tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Value</th></tr>
-<?php foreach ($syl_mail as $name => $value) { ?>
-<tr><td class="sylinfo_e"><?= htmlspecialchars($name) ?></td><td class="sylinfo_v"><?= SyL_UtilInfo::formatValue($value) ?></td></tr>
-<?php } ?>
-</table>
-<br />
-
-<h2>- ROUTER -</h2>
-
-<table border="0" cellpadding="3" width="600" class="sylinfo">
-<tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Value</th></tr>
-<?php foreach ($syl_router as $name => $value) { ?>
-<tr><td class="sylinfo_e"><?= htmlspecialchars($name) ?></td><td class="sylinfo_v"><?= SyL_UtilInfo::formatValue($value) ?></td></tr>
-<?php } ?>
-</table>
-<br />
-
-<h2>- SESSION -</h2>
-
-<table border="0" cellpadding="3" width="600" class="sylinfo">
-<tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Value</th></tr>
-<?php foreach ($syl_session as $name => $value) { ?>
-<tr><td class="sylinfo_e"><?= htmlspecialchars($name) ?></td><td class="sylinfo_v"><?= SyL_UtilInfo::formatValue($value) ?></td></tr>
-<?php } ?>
-</table>
-<br />
-
-<h2>- SMARTY -</h2>
-
-<table border="0" cellpadding="3" width="600" class="sylinfo">
-<tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Value</th></tr>
-<?php foreach ($syl_smarty as $name => $value) { ?>
-<tr><td class="sylinfo_e"><?= htmlspecialchars($name) ?></td><td class="sylinfo_v"><?= SyL_UtilInfo::formatValue($value) ?></td></tr>
-<?php } ?>
-</table>
-<br />
-
-<h2>- OTHER -</h2>
-
-<table border="0" cellpadding="3" width="600" class="sylinfo">
-<tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Value</th></tr>
-<?php foreach ($syl_other as $name => $value) { ?>
-<tr><td class="sylinfo_e"><?= htmlspecialchars($name) ?></td><td class="sylinfo_v"><?= SyL_UtilInfo::formatValue($value) ?></td></tr>
-<?php } ?>
-</table>
-<br />
-<?php } ?>
-
 
 <?php
 // =========================================================
