@@ -27,15 +27,15 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.4 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.5 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * Smarty饹
+ * Smartyӥ塼饹
  */
-require_once SYL_SMARTY_DIR . 'Smarty.class.php';
+require_once SYL_INCLUDE_DIR . "/framework/View/SyL_ViewSmarty.php";
 
 /**
  * Smarty쥤ȥ饹
@@ -44,36 +44,11 @@ require_once SYL_SMARTY_DIR . 'Smarty.class.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.4 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.5 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_ViewLayoutSmarty extends SyL_View
+class SyL_ViewLayoutSmarty extends SyL_ViewSmarty
 {
-    /**
-     * Smarty֥
-     * 
-     * @var object
-     */
-    var $smarty = null;
-
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     */
-    function SyL_ViewLayoutSmarty(&$dm)
-    {
-        parent::SyL_View($dm);
-
-        $this->smarty =& new Smarty();
-        $this->smarty->compile_dir = SYL_SMARTY_COMPILE_DIR;
-        $this->smarty->config_dir  = SYL_SMARTY_CONFIG_DIR;
-        $this->smarty->cache_dir   = SYL_SMARTY_CACHE_DIR;
-
-        // ƥĥפ򥻥å
-        $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
-    }
-
     /**
      * HTML󥰼¹
      * 
