@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.11 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.11 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -121,12 +121,19 @@ class SyL_DB
      */
     var $last_error_message = '';
     /**
-     * Хå᥽å
+     * SQLХå᥽å
      * 
      * @access protected
      * @var mixed
      */
-    var $callback_log = null;
+    var $callback_sql_log = null;
+    /**
+     * 顼Хå᥽å
+     * 
+     * @access protected
+     * @var mixed
+     */
+    var $callback_error_log = null;
 
     /**
      * 󥹥ȥ饯
@@ -140,6 +147,9 @@ class SyL_DB
     {
         set_magic_quotes_runtime(0);
         $this->dbname = $dbtype;
+
+        $this->callback_sql_log   = array(&$this, 'logSql');
+        $this->callback_error_log = array(&$this, 'logError');
     }
 
     /**
@@ -316,12 +326,8 @@ class SyL_DB
      */
     function beginTransaction()
     {
-        // SQL¸
-        $this->log('begin');
-          if (class_exists('SyL_Error')) {
-            $e =& SyL_Error::getInstance();
-            $e->resetErrorHandler();
-        }
+        // SQL
+        call_user_func($this->callback_sql_log, 'begin');
         $this->transaction = true;
         return true;
     }
@@ -333,12 +339,8 @@ class SyL_DB
      */
     function rollBack()
     {
-        // SQL¸
-        $this->log('rollback');
-        if (class_exists('SyL_Error')) {
-            $e =& SyL_Error::getInstance();
-            $e->setErrorHandler();
-        }
+        // SQL
+        call_user_func($this->callback_sql_log, 'rollback');
         $this->transaction = false;
         return true;
     }
@@ -350,12 +352,8 @@ class SyL_DB
      */
     function commit()
     {
-        // SQL¸
-        $this->log('commit');
-        if (class_exists('SyL_Error')) {
-            $e =& SyL_Error::getInstance();
-            $e->setErrorHandler();
-        }
+        // SQL
+        call_user_func($this->callback_sql_log, 'commit');
         $this->transaction = false;
         return true;
     }
@@ -377,8 +375,8 @@ class SyL_DB
      */
     function execRef($sql, &$result)
     {
-        // SQL¸
-        $this->log($sql);
+        // SQL
+        call_user_func($this->callback_sql_log, $sql);
 
         // ᥽å̾
         list($method) = explode(' ', $sql, 2);
@@ -629,7 +627,7 @@ class SyL_DB
      * @access public
      * @param boolean true: ȥꥬ顼ONfalse: ȥꥬ顼OFF
      */
-    function setTriggerError($trigger_error_flag)
+    function isTriggerError($trigger_error_flag)
     {
         $this->trigger_error_flag = ($trigger_error_flag === true);
     }
@@ -642,6 +640,8 @@ class SyL_DB
      */
     function triggerError()
     {
+        // SQL
+        call_user_func($this->callback_error_log, $this->getErrorMessage());
         if (!$this->transaction && $this->trigger_error_flag) {
             trigger_error($this->getErrorMessage(), E_USER_ERROR);
         }
@@ -785,12 +785,27 @@ class SyL_DB
      * @access public
      * @param mixed Хå᥽å
      */
-    function setCallbackLog($callback_log)
+    function setCallbackSqlLog($callback_sql_log)
     {
-        if (is_callable($callback_log)) {
-            $this->callback_log = $callback_log;
+        if (is_callable($callback_sql_log)) {
+            $this->callback_sql_log = $callback_sql_log;
         } else {
-            trigger_error("[SyL error] setCallbackLog argument invalid function (" . print_r($callback_log, true) . ")");
+            trigger_error("[SyL error] " . __FUNCTION__ . " argument invalid function (" . print_r($callback_sql_log, true) . ")");
+        }
+    }
+
+    /**
+     * 顼åХå᥽åɤ򥻥å
+     *
+     * @access public
+     * @param mixed 顼åХå᥽å
+     */
+    function setCallbackErrorLog($callback_error_log)
+    {
+        if (is_callable($callback_error_log)) {
+            $this->callback_error_log = $callback_error_log;
+        } else {
+            trigger_error("[SyL error] " . __FUNCTION__ . " argument invalid function (" . print_r($callback_error_log, true) . ")");
         }
     }
 
@@ -806,16 +821,23 @@ class SyL_DB
     }
 
     /**
-     * SQL¸
+     * ¹SQLʸ
      *
      * @access public
      * @param string SQLʸ
      */
-    function log($sql)
+    function logSql($sql)
+    {
+    }
+
+    /**
+     * 顼å
+     *
+     * @access public
+     * @param string 顼å
+     */
+    function logError($error_message)
     {
-        if ($this->callback_log != null) {
-            call_user_func($this->callback_log, $sql);
-        }
     }
 }
 
